from .client_proxy import ClientProxy
from .organization_periodic_usage import OrganizationPeriodicUsage


"""
contentful_management.organization_periodic_usages_proxy
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

This module implements the OrganizationPeriodicUsagesProxy class.

API reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/usage

:copyright: (c) 2020 by Contentful GmbH.
:license: MIT, see LICENSE for more details.
"""


class OrganizationPeriodicUsagesProxy(ClientProxy):
    """
    API reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/usage
    """

    def __init__(self, client, organization_id):
        super(OrganizationPeriodicUsagesProxy, self).__init__(client, None)
        self.organization_id = organization_id

    @property
    def _resource_class(self):
        return OrganizationPeriodicUsage

    def all(self, query=None, *args, **kwargs):
        """
        Gets all organization periodic usage.
        """

        if query is None:
            query = {}

        return self.client._get(
            self._url(),
            query
        )

    def create(self, file_or_path, **kwargs):
        """
        Not supported.
        """

        raise Exception("Not supported")

    def find(self, *args, **kwargs):
        """
        Not supported.
        """

        raise Exception("Not supported")

    def delete(self, upload_id):
        """
        Not supported.
        """

        raise Exception("Not supported")

    def _url(self):
        return self._resource_class.base_url(self.organization_id)

    def __repr__(self):
        return "<{0} organization_id='{1}'>".format(
            self.__class__.__name__,
            self.organization_id
        )



from .resource import Resource


"""
contentful_management.organization_periodic_usage
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

This module implements the OrganizationPeriodicUsage class.

API reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/usage

:copyright: (c) 2020 by Contentful GmbH.
:license: MIT, see LICENSE for more details.
"""


class OrganizationPeriodicUsage(Resource):
    """
    API reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/usage
    """

    def __init__(self, item, **kwargs):
        super(OrganizationPeriodicUsage, self).__init__(item, **kwargs)

        self.unit_of_measure = item.get('unitOfMeasure', None)
        self.metric = item.get('metric', None)
        self.usage = item.get('usage', None)
        self.usage_per_day = item.get('usagePerDay', None)
        self.date_range = item.get('dateRange', None)

    def _linkables(self):
        return super(OrganizationPeriodicUsage, self)._linkables() + ['organization']

    @classmethod
    def base_url(klass, organization_id):
        return "organizations/{0}/organization_periodic_usages".format(organization_id)

    def __repr__(self):
        return "<OrganizationPeriodicUsage id='{0}'>".format(
            self.sys.get('id', '')
        )



from .space_resource_proxy import SpaceResourceProxy
from .webhooks_proxy import WebhooksProxy


"""
contentful_management.space_webhooks_proxy
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

This module implements the SpaceWebhooksProxy class.

API reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/webhooks

:copyright: (c) 2018 by Contentful GmbH.
:license: MIT, see LICENSE for more details.
"""


class SpaceWebhooksProxy(SpaceResourceProxy):
    """
    API reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/webhooks
    """

    def _resource_proxy_class(self):
        return WebhooksProxy

    def create(self, attributes=None, **kwargs):
        """
        Creates a webhook with given attributes.
        """

        return super(SpaceWebhooksProxy, self).create(None, attributes)



from .client_proxy import ClientProxy
from .user import User

"""
contentful_management.organization_users_proxy
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

This module implements the OrganizationUsersProxy class.

API reference: https://www.contentful.com/developers/docs/references/user-management-api/#/reference/users

:copyright: (c) 2020 by Contentful GmbH.
:license: MIT, see LICENSE for more details.
"""


class OrganizationUsersProxy(ClientProxy):
    """
    API reference: https://www.contentful.com/developers/docs/references/user-management-api/#/reference/users
    """

    def __init__(self, client, organization_id):
        super(OrganizationUsersProxy, self).__init__(client, None)
        self.organization_id = organization_id

    @property
    def _resource_class(self):
        return User

    def _url(self, resource_id=None, **kwargs):
        return self._resource_class.base_url(None, resource_id=resource_id, organization_id=self.organization_id, **kwargs)



from .client_proxy import ClientProxy
from .tag import Tag

"""
contentful_management.tags_proxy
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

This module implements the TagsProxy class.

API reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/tags

:copyright: (c) 2023 by Contentful GmbH.
:license: MIT, see LICENSE for more details.
"""


class TagsProxy(ClientProxy):
    """
    API reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/tags
    """

    @property
    def _resource_class(self):
        return Tag



from .space_resource_proxy import SpaceResourceProxy
from .users_proxy import UsersProxy

"""
contentful_management.space_users_proxy
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

This module implements the SpaceUsersProxy class.

API reference: https://www.contentful.com/developers/docs/references/user-management-api/#/reference/users

:copyright: (c) 2018 by Contentful GmbH.
:license: MIT, see LICENSE for more details.
"""


class SpaceUsersProxy(SpaceResourceProxy):
    """
    API reference: https://www.contentful.com/developers/docs/references/user-management-api/#/reference/users
    """

    def _resource_proxy_class(self):
        return UsersProxy



from .resource import Resource

"""
contentful_management.tag
~~~~~~~~~~~~~~~~~~~~~~~~~

This module implements the Tag class.

API reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/tags

:copyright: (c) 2023 by Contentful GmbH.
:license: MIT, see LICENSE for more details.
"""


class Tag(Resource):
    """
    API reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/tags
    """

    def __init__(self, item, **kwargs):
        super(Tag, self).__init__(item, **kwargs)
        self.name = item.get('name', '')

    def delete(self):
        """
        Deletes this tag.
        """
        return self._client._delete(
            self.__class__.base_url(
                space_id=self.space.id,
                resource_id=self.sys['id'],
                environment_id=self._environment_id,
            ),
            headers=self._update_headers()
        )

    def __repr__(self):
        return "<Tag id='{0}' name='{1}'>".format(
            self.sys.get('id', ''),
            self.name
        )



from .client_proxy import ClientProxy
from .environment import Environment

"""
contentful_management.environment_proxy
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

This module implements the EnvironmentsProxy class.

API reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/spaces

:copyright: (c) 2018 by Contentful GmbH.
:license: MIT, see LICENSE for more details.
"""


class EnvironmentsProxy(ClientProxy):
    """
    API reference: https://www.contentful.com/developers/docs/references/content-management-api/
    """

    def __init__(self, client, space_id):
        super(EnvironmentsProxy, self).__init__(client, space_id)

    @property
    def _resource_class(self):
        return Environment



from .resource import Resource
from .space_periodic_usages_proxy import SpacePeriodicUsagesProxy
from .organization_periodic_usages_proxy import OrganizationPeriodicUsagesProxy
from .organization_users_proxy import OrganizationUsersProxy


"""
contentful_management.organization
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

This module implements the Organization class.

API reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/organizations

:copyright: (c) 2018 by Contentful GmbH.
:license: MIT, see LICENSE for more details.
"""


class Organization(Resource):
    """
    API reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/organizations
    """

    def __init__(self, item, **kwargs):
        super(Organization, self).__init__(item, **kwargs)
        self.name = item.get('name', '')

    @classmethod
    def base_url(klass, *args, **kwargs):
        """
        Returns the URI for the organization.
        """

        return "organizations"

    def periodic_usages(self):
        """
        Provides access to organization periodic usages management methods.

        API reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/usage

        :return: :class:`OrganizationPeriodicUsagesProxy <contentful_management.organization_periodic_usages_proxy.OrganizationPeriodicUsagesProxy>` object.
        :rtype: contentful.organization_periodic_usages_proxy.OrganizationPeriodicUsagesProxy

        Usage:

            >>> organization_periodic_usages_proxy = organization.usage_periods()
            <OrganizationPeriodicUsagesProxy organization_id="cfexampleapi">
        """

        return OrganizationPeriodicUsagesProxy(self._client, self.id)

    def space_periodic_usages(self):
        """
        Provides access to organization periodic usages grouped by space management methods.

        API reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/usage

        :return: :class:`SpacePeriodicUsagesProxy<contentful_management.space_periodic_usages_proxy.SpacePeriodicUsagesProxy>` object.
        :rtype: contentful.space_periodic_usages_proxy.SpacePeriodicUsagesProxy

        Usage:

            >>> space_periodic_usages_proxy = organization.space_usage_periods()
            <SpacePeriodicUsagesProxyorganization_id="cfexampleapi">
        """

        return SpacePeriodicUsagesProxy(self._client, self.id)

    def users(self):
        """
        Provides access to organization users management methods.

        API reference: https://www.contentful.com/developers/docs/references/user-management-api/#/reference/users

        :return: :class:`OrganizationUsersProxy <contentful_management.organization_users_proxy.OrganizationUsersProxy>` object.
        :rtype: contentful.organization_users_proxy.OrganizationUsersProxy

        Usage:

            >>> organization_users_proxy = organization.users()
            <OrganizationUsersProxy organization_id="cfexampleapi">
        """

        return OrganizationUsersProxy(self._client, self.id)

    def __repr__(self):
        return "<Organization[{0}] id='{1}'>".format(
            self.name,
            self.id
        )



from .space_resource_proxy import SpaceResourceProxy
from .space_memberships_proxy import SpaceMembershipsProxy


"""
contentful_management.space_space_memberships_proxy
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

This module implements the SpaceSpaceMembershipsProxy class.

API reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/space-memberships

:copyright: (c) 2018 by Contentful GmbH.
:license: MIT, see LICENSE for more details.
"""


class SpaceSpaceMembershipsProxy(SpaceResourceProxy):
    """
    API reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/space-memberships
    """

    def _resource_proxy_class(self):
        return SpaceMembershipsProxy

    def create(self, attributes=None, **kwargs):
        """
        Creates a space membership with given attributes.
        """

        return super(SpaceSpaceMembershipsProxy, self).create(None, attributes)
